@@ -9,7 +9,6 @@ class Migration(migrations.Migration):
     initial = True
 
     operations = [
-
         migrations.CreateModel(
             "Author",
             [
@@ -20,7 +19,6 @@ class Migration(migrations.Migration):
                 ("silly_field", models.BooleanField(default=False)),
             ],
         ),
-
         migrations.CreateModel(
             "Tribble",
             [
@@ -28,10 +26,13 @@ class Migration(migrations.Migration):
                 ("fluffy", models.BooleanField(default=True)),
             ],
         ),
-
+        migrations.AddField(
+            model_name='tribble',
+            name='bool',
+            field=models.BooleanField(default=False),
+        ),
         migrations.AlterUniqueTogether(
             name='author',
             unique_together=set([('name', 'slug')]),
         ),
-
     ]
